# Generated by Django 5.0.3 on 2024-03-27 05:19

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('django_bocor_ds', '0003_portfolio_redirect_link'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='portfolio',
            name='redirect_link',
        ),
    ]
