{% load static %}

<section id="contact" class="contact section-bg">
      <div class="container" data-aos="fade-up">

        <div class="section-title">
          <h2>Contact</h2>
          <p>{{ contact.desc }}</p>
        </div>

        <div class="row">

          <div class="col-lg-6">

            <div class="row">
              <div class="col-md-12">
                <div class="info-box" data-aos="fade-up">
                  <i class="bx bx-map"></i>
                  <h3>Our Address</h3>
                  {% autoescape off%}
                  <p>{{ contact.address }}</p>
                  {% endautoescape %}
                </div>
              </div>
              <div class="col-md-6">
                <div class="info-box mt-4" data-aos="fade-up" data-aos-delay="100">
                  <i class="bx bx-envelope"></i>
                  <h3>Email Us</h3>
                  {% autoescape off %}
                  <p>{{ contact.email }}</p>
                  {% endautoescape %}
                </div>
              </div>
              <div class="col-md-6">
                <div class="info-box mt-4" data-aos="fade-up" data-aos-delay="100">
                  <i class="bx bx-phone-call"></i>
                  <h3>Call Us</h3>
                  {% autoescape off %}
                  <p>{{ contact.phone }}</p>
                  {% endautoescape %}
                </div>
              </div>
            </div>

          </div>

          <div class="col-lg-6 mt-4 mt-lg-0">
            <form action="{% url 'bocords:home' %}" method="POST" role="form" class="php-email-form  w-100" data-aos="fade-up"">
              {% csrf_token %}
              <div class="row">
                <div class="col-md-6 form-group">
                  {{ form.name }}
                </div>
                <div class="col-md-6 form-group mt-3 mt-md-0">
                  {{ form.email }}
                </div>
              </div>
              <div class="form-group mt-3">
                {{ form.company }}
              </div>
              <div class="form-group mt-3">
                {{ form.message }}
              </div>
              <div class="my-3">
                {% if post_message %}
                <div class="alert alert-success alert-dismissible fade show " role="alert">
                  {{ post_message }}
                  <button type="button" class="btn-close" data-bs-dismiss="alert" aria-label="Close"></button>
                </div>
                {% endif %}
              </div>
              <div class="text-center"><button type="submit">문의하기</button></div>
            </form>
          </div>

        </div>

      </div>
    </section>