/*--------------------------------------------------------------
# Footer
--------------------------------------------------------------*/
#footer {
  background: url("../img/footer-bg.jpg") center center no-repeat;
  color: $white;
  font-size: 14px;
  position: relative;

  &::before {
    content: "";
    position: absolute;
    left: 0;
    right: 0;
    top: 0;
    bottom: 0;
    background: rgba(darken($secondary, 5), .85);
    z-index: 1;
  }

  .footer-top {
    position: relative;
    z-index: 2;
    text-align: center;
    padding: 80px 0;

    h3 {
      font-size: 36px;
      font-weight: 700;
      color: $white;
      position: relative;
      font-family: $font-secondary;
      padding-bottom: 0;
      margin-bottom: 0;
    }

    p {
      font-size: 15;
      font-style: italic;
      margin: 30px 0 0 0;
      padding: 0;
    }

    .footer-newsletter {
      text-align: center;
      font-size: 15px;
      margin-top: 30px;
  
      form {
        background: #fff;
        padding: 6px 10px;
        position: relative;
        border-radius: 50px;
        box-shadow: 0px 2px 15px rgba(0, 0, 0, 0.10);
        text-align: left;
  
        input[type="email"] {
          border: 0;
          padding: 4px 8px;
          width: calc(100% - 100px);
        }
  
        input[type="submit"] {
          position: absolute;
          top: 0;
          right: -1px;
          bottom: 0;
          border: 0;
          background: none;
          font-size: 16px;
          padding: 0 20px;
          background: $primary;
          color: $white;
          transition: 0.3s;
          border-radius: 50px;
          box-shadow: 0px 2px 15px rgba(0, 0, 0, 0.10);
          &:hover {
            background: darken($primary, 10);
          }
        }
      }
    }

    .social-links {
      margin-top: 30px;
      a {
        font-size: 18px;
        display: inline-block;
        background:lighten($secondary, 5);
        color: $white;
        line-height: 1;
        padding: 8px 0;
        margin-right: 4px;
        border-radius: 50%;
        text-align: center;
        width: 36px;
        height: 36px;
        transition: 0.3s;
        &:hover {
          background: darken($primary, 10);
          color: #fff;
          text-decoration: none;
        }
      }
    }

  }

  .footer-bottom {
    border-top: 1px solid darken($secondary, 5);
    z-index: 2;
    position: relative;
    padding-top: 40px;
    padding-bottom: 40px;
  }

  .copyright {
    text-align: center;
    float: left;
  }

  .credits {
    float: right;
    text-align: center;
    font-size: 13px;
  }

  @media (max-width: 768px) {
    .copyright, .credits {
      padding: 5px;
      float: none;
      text-align: ceneter;
    }
  }
}
