{% load static %}
{% load bocords_tags %}
{% load django_calendards_tags %}
{% load django_modalds_tags %}
{% load django_analyticsds_tags %}

<!DOCTYPE html>
<html lang="en">

<head>
  <!-- ======= SEO ======= -->{% include 'bocords/seo.html' %}<!-- End SEO -->

  <!-- Vendor CSS Files -->
  <link rel="stylesheet"
        href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.3/dist/css/bootstrap.min.css" crossorigin="anonymous">
  <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/bootstrap-icons@1.11.3/font/bootstrap-icons.min.css">
  <link href="{% static 'bocords/vendor/aos/aos.css' %}" rel="stylesheet">
  <link href="{% static 'bocords/vendor/boxicons/css/boxicons.min.css' %}" rel="stylesheet">
  <link href="{% static 'bocords/vendor/glightbox/css/glightbox.min.css' %}" rel="stylesheet">
  <link href="{% static 'bocords/vendor/swiper/swiper-bundle.min.css' %}" rel="stylesheet">

  <!-- Template Main CSS File -->
  <link href="{% static 'bocords/css/style.css' %}" rel="stylesheet">

</head>

<body>

  <!-- ======= Header ======= -->{% include 'bocords/header.html' %}<!-- End Header -->

  <!-- ======= Hero Section ======= -->{% hero %}<!-- End Hero -->

  <main id="main">
    {% show_calendar %}
    {% show_modal %}
    {% make_analytics %}

    {% for component, is_use, _, _ in components %}
      {% if is_use %}
        {% if component == 'clients' %}
          <!-- ======= Clients Section ======= -->{% clients %}<!-- End Clients Section -->
        {% elif component == 'about' %}
          <!-- ======= About Section ======= -->{% about %}<!-- End About Section -->
        {% elif component == 'services' %}
          <!-- ======= Services Section ======= -->{% services %}<!-- End Services Section -->
        {% elif component == 'features' %}
          <!-- ======= Features Section ======= -->{% features %}<!-- End Features Section -->
        {% elif component == 'portfolio' %}
          <!-- ======= Portfolio Section ======= -->{% portfolio %}<!-- End Portfolio Section -->
        {% elif component == 'team' %}
          <!-- ======= Team Section ======= -->{% team %}<!-- End Team Section -->
        {% elif component == 'pricing' %}
          <!-- ======= Pricing Section ======= -->{% pricing %}<!-- End Pricing Section -->
        {% elif component == 'faq' %}
          <!-- ======= Frequently Asked Questions Section ======= -->{% faq %}<!-- End Frequently Asked Questions Section -->
        {% elif component == 'contact' %}
          <!-- ======= Contact Section ======= -->{% contact %}<!-- End Contact Section -->
        {% endif %}
      {% endif %}
    {% endfor %}
  </main><!-- End #main -->

  <!-- ======= Footer ======= -->{% include 'bocords/footer.html' %}<!-- End Footer -->

  <a href="#" class="back-to-top d-flex align-items-center justify-content-center"><i class="bi bi-arrow-up-short"></i></a>

  <!-- Vendor JS Files -->
  <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.3/dist/js/bootstrap.bundle.min.js"
          crossorigin="anonymous"></script>
  <script src="{% static 'bocords/vendor/aos/aos.js' %}"></script>
  <script src="{% static 'bocords/vendor/glightbox/js/glightbox.min.js' %}"></script>
  <script src="{% static 'bocords/vendor/isotope-layout/isotope.pkgd.min.js' %}"></script>
  <script src="{% static 'bocords/vendor/swiper/swiper-bundle.min.js' %}"></script>
  <!--<script src="{% static 'bocords/vendor/php-email-form/validate.js' %}"></script>-->

  <!-- Template Main JS File -->
  <script src="{% static 'bocords/js/main.js' %}"></script>
</body>
</html>