{% load static %}

<style>
#footer {
  background: url("{% static 'bocords/img/footer-bg.jpg' %}") center center no-repeat;
  color: #fff;
  font-size: 14px;
  position: relative;
}
</style>

<footer id="footer">

    <div class="footer-top">

      <div class="container">

        <div class="row  justify-content-center">
          <div class="col-lg-6">
            <h3>{{ footer.h3 }}</h3>
            <p>{{ footer.p }}</p>
          </div>
        </div>

        <!--
        <div class="row footer-newsletter justify-content-center">
          <div class="col-lg-6">
            <form action="" method="post">
              <input type="email" name="email" placeholder="Enter your Email"><input type="submit" value="Subscribe">
            </form>
          </div>
        </div>
        -->

        <div class="social-links">
          {% if social.twitter %}
          <a href="{{ footer.social.twitter }}" class="twitter" title="{{ basic_info.clinic }} 트위터 바로가기" target="_blank"><i class="bi bi-twitter"></i></a>
          {% endif %}
          {% if social.facebook %}
          <a href="{{ footer.social.facebook }}" class="facebook" title="{{ basic_info.clinic }} 페이스북 바로가기" target="_blank"><i class="bi bi-facebook"></i></a>
          {% endif %}
          {% if social.instagram %}
          <a href="{{ footer.social.instagram }}" class="instagram" title="{{ basic_info.clinic }} 인스타그램 바로가기" target="_blank"><i class="bi bi-instagram"></i></a>
          {% endif %}
          {% if social.youtube %}
          <a href="{{ footer.social.youtube }}" class="youtube" title="{{ basic_info.clinic }} 유튜브 바로가기" target="_blank"><i class="bi bi-youtube"></i></a>
          {% endif %}
          {% if social.blog %}
            <a href="{{ footer.social.blog }}" class="blog" title="{{ basic_info.clinic }} 블로그 바로가기" target="_blank"><i class="bi bi-bootstrap-fill"></i></a>
          {% endif %}
        </div>

      </div>
    </div>

    <div class="container footer-bottom clearfix">
      <div class="copyright">
        &copy; Copyright <a href="https://demiansoft.com" target="_blank"><strong><span>Demiansoft</span></strong></a><a href="https://map.naver.com/v5/entry/place/13289684?c=15,0,0,0,dh" target="_blank">.</a> All Rights Reserved
      </div>

    </div>
  </footer>