# Generated by Django 5.0.3 on 2024-03-26 07:22

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='Category',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('filter', models.CharField(max_length=20, verbose_name='카테고리')),
            ],
        ),
        migrations.CreateModel(
            name='Portfolio',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('title', models.CharField(max_length=20, verbose_name='제목')),
                ('subtitle', models.CharField(max_length=40, verbose_name='부제목')),
                ('description', models.TextField(blank=True, null=True, verbose_name='세부 설명')),
                ('image1', models.ImageField(help_text='각 이미지 비율이(3x5) 동일한 것이 보기 좋습니다.', null=True, upload_to='images/portfolio/')),
                ('image2', models.ImageField(blank=True, null=True, upload_to='images/portfolio/')),
                ('image3', models.ImageField(blank=True, null=True, upload_to='images/portfolio/')),
                ('image4', models.ImageField(blank=True, null=True, upload_to='images/portfolio/')),
                ('image5', models.ImageField(blank=True, null=True, upload_to='images/portfolio/')),
                ('url', models.URLField(blank=True, help_text='공란 가능', max_length=500, null=True, verbose_name='참고링크')),
                ('filter', models.ForeignKey(on_delete=django.db.models.deletion.PROTECT, related_name='category', to='django_bocor_ds.category')),
            ],
        ),
    ]
