/*--------------------------------------------------------------
# Header
--------------------------------------------------------------*/
#header {
  z-index: 997;
  transition: all 0.5s;
  padding: 16px 0;
  background: $secondary;

  .logo {

    h1 {
      font-size: 24px;
      margin: 0;
      padding: 10px 0;
      line-height: 1;
      font-weight: 700;
      letter-spacing: 3px;
      text-transform: uppercase;
      font-family: $font-secondary;
    }

    h1 a, h1 a:hover {
      color: #fff;
      text-decoration: none;
      span {
        color: $primary;
      }
    }

    img {
      padding: 0;
      margin: 0;
      max-height: 40px;
    }
  }
}
