# Generated by Django 5.0.3 on 2024-03-26 08:05

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('django_bocor_ds', '0001_initial'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='portfolio',
            name='image3',
        ),
        migrations.RemoveField(
            model_name='portfolio',
            name='image4',
        ),
        migrations.RemoveField(
            model_name='portfolio',
            name='image5',
        ),
    ]
